# -*- coding: ascii -*-
"""
This package reads the different paths mentioned in the dset.cfg file and populates paths dictionary.
This module is common for both Windows and Linux.

Classes:
    None

Exceptions:
    None

Functions:
    None
"""
import os
import configparser

paths = {}
logtype = {}
porttype = {}

objCfg = configparser.ConfigParser()
try:
    
    dsethome = None
    
    if os.name == "nt":
        # Try to read information from environment variables first, if not fall back and read from registry
        strVal = None
        strVal = os.getenv("ESupportToolPath")
        if strVal is None:
            strVal = os.getenv("PythonHome")
            if strVal is None:
                import winreg
                objKey = winreg.OpenKey(winreg.HKEY_LOCAL_MACHINE, "SOFTWARE\DELL\DellSystemESupportTool")
                strVal, nType = winreg.QueryValueEx(objKey, "ESupportToolPath")
        if strVal is not None:
            dsethome = strVal.rpartition("\\")[0]
    elif os.name == "posix":
        dsethome = os.getenv("DSETHOME")

    #dsethome will be set by above code for windows/linux and that will be used for reading the location of the config file later. 
    if dsethome is not None:
        objCfg.read(os.path.expandvars(dsethome+"//config//dset.cfg"))
    else:
        #setting the default path in case of linux since this will not generate any logs.
        if os.name == "posix":
            objCfg.read("//opt//dell//advdiags//dset//config//dset.cfg")
            os.environ["DSETHOME"] = "//opt//dell//advdiags//dset"

except:
    print("Not able to find dset.cfg file")
else:
    if objCfg.has_section("Paths"):
        lstItems = objCfg.items("Paths")
        for option, value in lstItems:
            paths[option] = os.path.expandvars(value)
    if objCfg.has_section("Logtype"):
        lstItems = objCfg.items("Logtype")
        for option, value in lstItems:
            logtype[option] = os.path.expandvars(value)
    if objCfg.has_section("Porttype"):
        lstItems = objCfg.items("Porttype")
        for option, value in lstItems:
            porttype[option] = os.path.expandvars(value)
