#!/bin/bash
# DSET should not be installed when a report collection is in progress.
collector_running=`ps -A | grep collector`
dellsysteminfo_running=`ps -A | grep dellsysteminfo`
if [ "$collector_running" != "" ] && [ "$dellsysteminfo_running" != "" ]; then
	echo -e "\nCannot uninstall Dell System E-support Tool when the DSET report collection is in progress. Please wait for the report collection process to complete and then retry.\n"
	exit
fi

echo -e "\033[33mCleaning up DSET deployed components .... [ Please wait ]\033[0m"
export PYTHONHOME="/opt/dell/advdiags/dset/bin"
export PYTHONPATH="/opt/dell/advdiags/dset/bin":"/opt/dell/advdiags/dset/bin/lib"

# Redirection output variable 
if [ "$DEBUG" == "" ]; then
	REDIRECT_OUTPUT=/dev/null
else
	REDIRECT_OUTPUT=/tmp/dsetuninstall.log
fi

#--------------------------------------------------------------------------------------------#
# Function to check if the symbolic links were made by us and still exists and delete if true 
#--------------------------------------------------------------------------------------------# 
function CheckLink_And_Delete
{
	First_Argument=$1
	Second_Argument=$2
	base=$(/bin/basename $First_Argument)
	Link_Created_By_DSET=`grep "SYMLINKENTRIES" /opt/dell/advdiags/dset/bin/packages/.sfcbpkglist -r | grep $base`
	SYMLINKEXIST=`ls -l  $First_Argument 2>&1 | grep $Second_Argument`
	if [[ "$Link_Created_By_DSET" != "" ]] && [[ "$SYMLINKEXIST" != "" ]]; then
		rm -rf $First_Argument
	fi
}

TOGPEG_RUN_STATUS="FALSE"
ACTION="NONE"
#----------------------------------------------#
# Check if Remote Provide is installed or not
#----------------------------------------------#
rpm -q dell-dset-provider >> $REDIRECT_OUTPUT 2>&1
if test $? -eq 0; then
	# Revert back the changes done to configuration files during installation
	/opt/dell/advdiags/dset/bin/python /opt/dell/advdiags/dset/bin/uninstallconfig.py
	
	# SFCB unstage
	sfcbunstage -n root/dsetcim /var/lib/sfcb/stage/mofs/root/dsetcim/*.mof >> $REDIRECT_OUTPUT 2>&1
	rm -rf /var/lib/sfcb/stage/mofs/root/dsetcim

	# Check the case of ESX first
	if [ -f /etc/vmware-release ]; then
		sfcbunstage -n root/dsetcim /var/lib/sfcb/stage/regs/dset-providerRegister >> $REDIRECT_OUTPUT 2>&1
		rm -rf /var/lib/sfcb/stage/regs/dset-providerRegister
		rm -rf /var/lib/sfcb/registration/dset-providerRegister
		rm -rf /opt/dell/advdiags/dset/bin/mof/reg/* >> $REDIRECT_OUTPUT 2>&1
		rm -rf /var/lib/sfcb/registration/repository/root/dsetcim
		SFCB_NOT_RUNNING=`grep "SFCB_NOT_RUNNING" /opt/dell/advdiags/dset/bin/packages/.sfcbpkglist -r`
		if [ "$SFCB_NOT_RUNNING" != "" ]; then
			SFCB_RUN_PRE_STATUS="NOT_RUNNING"
		fi
 
		SFCB_RUNNING=`grep "SFCB_RUNNING" /opt/dell/advdiags/dset/bin/packages/.sfcbpkglist -r`
		if [ "$SFCB_RUNNING" != "" ]; then
			SFCB_RUN_PRE_STATUS="RUNNING"
		fi
		
	else
		sfcbunstage -n root/dsetcim /var/lib/sfcb/stage/regs/*.reg >> $REDIRECT_OUTPUT 2>&1
		rm -rf /var/lib/sfcb/stage/regs/DCIM_*.reg >> $REDIRECT_OUTPUT 2>&1
		rm -rf /opt/dell/advdiags/dset/bin/mof/reg/* >> $REDIRECT_OUTPUT 2>&1 
		rm -rf /var/lib/sfcb/registration/repository/root/dsetcim
  
		SFCB_RUN_PRE_STATUS=""
		rpm -q tog-pegasus >> $REDIRECT_OUTPUT 2>&1
		if test $? -eq 0; then
			service tog-pegasus  status >$REDIRECT_OUTPUT 2>&1
			if test $? -eq 0; then
				cimprovider -r -m DsetCmpiProvider >> $REDIRECT_OUTPUT 2>&1
				rm -rf /var/lib/Pegasus/repository/root#dsetcim
				service tog-pegasus stop >> $REDIRECT_OUTPUT 2>&1
				rm -rf /usr/lib/cmpi/libpyDsetCmpiProvider.so >> $REDIRECT_OUTPUT 2>&1
				rm -rf /usr/lib64/cmpi/libpyDsetCmpiProvider.so >> $REDIRECT_OUTPUT 2>&1
				service tog-pegasus start >> $REDIRECT_OUTPUT 2>&1
				TOGPEG_RUN_STATUS="TRUE"
			fi
		fi  
	fi
	SFCB_Service_Enabled=`grep "SFCB_SERVICE_ENABLED" /opt/dell/advdiags/dset/bin/packages/.sfcbpkglist -r`
	SFCB_chkconfig_init_Level=`grep "2:\|3:\|5:"  /opt/dell/advdiags/dset/bin/packages/.sfcbpkglist -r|grep CIMOM`
	SFCB_init_Level_2=`echo $SFCB_chkconfig_init_Level | grep '2:off' -o -E`
	SFCB_init_Level_3=`echo $SFCB_chkconfig_init_Level | grep '3:off' -o -E`
	SFCB_init_Level_5=`echo $SFCB_chkconfig_init_Level | grep '5:off' -o -E`
	CIMOM_ADDED=`grep "CIMOM_Service_added" /opt/dell/advdiags/dset/bin/packages/.sfcbpkglist -r`
	
	IPMI_Service_Enabled=`grep "IPMI_SERVICE_ENABLED" /opt/dell/advdiags/dset/bin/packages/.sfcbpkglist -r`
	IPMI_chkconfig_init_Level=`grep "2:\|3:\|5:"  /opt/dell/advdiags/dset/bin/packages/.sfcbpkglist -r|grep ipmi`
	IPMI_init_Level_2=`echo $IPMI_chkconfig_init_Level | grep '2:off' -o -E`
	IPMI_init_Level_3=`echo $IPMI_chkconfig_init_Level | grep '3:off' -o -E`
	IPMI_init_Level_5=`echo $IPMI_chkconfig_init_Level | grep '5:off' -o -E`
	IPMI_ADDED=`grep "IPMI_Service_added" /opt/dell/advdiags/dset/bin/packages/.sfcbpkglist -r`
	
	CIMOM_NAME="NONE"
	if [ "$SFCB_Service_Enabled" == "SBLIM-SFCB_SERVICE_ENABLED" ]; then 
		CIMOM_NAME="sblim-sfcb"
	elif [ "$SFCB_Service_Enabled" == "SFCB_SERVICE_ENABLED" ]; then 
		CIMOM_NAME="sfcb"
	fi
    #Compare the list of providers registered at the time of dset uninstallation and dset installation to check if there are other non-dset
	#providers registered. If yes then we do not need to uninstall the sfcb installed by dset.
	diff /var/lib/sfcb/registration/providerRegister /opt/dell/advdiags/dset/bin/packages/.providerRegister_dset_back >> $REDIRECT_OUTPUT 2>&1
        DELETE_DSETSFCB=$?
    #Undoing all the chkconfig settings for ipmi at install time
	if [ "$IPMI_chkconfig_init_Level" != "" ] ; then
		if [ "$IPMI_init_Level_2" != "" ]; then
			chkconfig --level 2  ipmi off
		fi
		if [ "$IPMI_init_Level_3" != "" ]; then
			chkconfig --level 3  ipmi off
		fi
		if [ "$IPMI_init_Level_5" != "" ]; then
			chkconfig --level 5  ipmi off
		fi	
	fi
	if [ "$IPMI_ADDED" != "" ] ; then 		 
		chkconfig --del ipmi >> $REDIRECT_OUTPUT 2>&1
	fi
	rpm -q srvadmin-omacore >> $REDIRECT_OUTPUT 2>&1
	if test $? -eq 0; then
		rpm -e dell-dset-provider >> $REDIRECT_OUTPUT 2>&1
		if [ "$1" != "TRUE" ]; then
			rpm -e dell-dset-collector >> $REDIRECT_OUTPUT 2>&1
		fi
		rpm -e dell-dset-common >> $REDIRECT_OUTPUT 2>&1
		PKGLIST=`grep "dell-dset-provider_basesfcb" /opt/dell/advdiags/dset/bin/packages/.sfcbpkglist -r`
		if [ "$PKGLIST" != "" ]; then
			rpm -e dell-dset-provider_basesfcb >> $REDIRECT_OUTPUT 2>&1
		fi
		PKGLIST=`grep "dell-dset-provider_basetog" /opt/dell/advdiags/dset/bin/packages/.sfcbpkglist -r`
		if [ "$PKGLIST" != "" ]; then
			rpm -e dell-dset-provider_basetog >> $REDIRECT_OUTPUT 2>&1
		fi
		PKGLIST=`grep "dell-dset-provider_basesfcb_Watchdog" /opt/dell/advdiags/dset/bin/packages/.sfcbpkglist -r`
		if [ "$PKGLIST" != "" ]; then
			rpm -e dell-dset-provider_basesfcb_Watchdog >> $REDIRECT_OUTPUT 2>&1
		fi
		if [ "$DELETE_DSETSFCB" == "0" ] ; then
			if [ "$SFCB_chkconfig_init_Level" != "" ] ; then
				if [ "$SFCB_init_Level_2" != "" ]; then
					chkconfig --level 2  $CIMOM_NAME off
				fi
				if [ "$SFCB_init_Level_3" != "" ]; then
					chkconfig --level 3  $CIMOM_NAME off
				fi
				if [ "$SFCB_init_Level_5" != "" ]; then
					chkconfig --level 5  $CIMOM_NAME off
				fi	
			fi 
	
			if [ "$CIMOM_ADDED" != "" ] ; then 		 
				chkconfig --del $CIMOM_NAME >> $REDIRECT_OUTPUT 2>&1
			fi
		
			PKGLIST=`grep "sblim-cmpi-base" /opt/dell/advdiags/dset/bin/packages/.sfcbpkglist -r`
			if [ "$PKGLIST" != "" ]; then
				rpm -e sblim-cmpi-base --nodeps >> $REDIRECT_OUTPUT 2>&1
			fi

			PKGLIST=`grep "sblim-indication_helper" /opt/dell/advdiags/dset/bin/packages/.sfcbpkglist -r`
			if [ "$PKGLIST" != "" ]; then
				rpm -e sblim-indication_helper >> $REDIRECT_OUTPUT 2>&1
			fi

			PKGLIST=`grep "sblim-sfcb" /opt/dell/advdiags/dset/bin/packages/.sfcbpkglist -r`
			if [ "$PKGLIST" != "" ]; then
				rpm -e sblim-sfcb >> $REDIRECT_OUTPUT 2>&1
			fi
            
			PKGLIST=`grep "cim-schema" /opt/dell/advdiags/dset/bin/packages/.sfcbpkglist -r`
			if [ "$PKGLIST" != "" ]; then
				rpm -e cim-schema >> $REDIRECT_OUTPUT 2>&1
			fi
	 
			SFCB_NOT_RUNNING=`grep "SFCB_NOT_RUNNING" /opt/dell/advdiags/dset/bin/packages/.sfcbpkglist -r`
			if [ "$SFCB_NOT_RUNNING" != "" ]; then
				SFCB_RUN_PRE_STATUS="NOT_RUNNING"
			fi
	 
			SFCB_RUNNING=`grep "SFCB_RUNNING" /opt/dell/advdiags/dset/bin/packages/.sfcbpkglist -r`
			if [ "$SFCB_RUNNING" != "" ]; then
				SFCB_RUN_PRE_STATUS="RUNNING"
			fi
        fi
	 
	else
		rpm -e dell-dset-provider >> $REDIRECT_OUTPUT 2>&1
		if [ "$1" != "TRUE" ]; then
			rpm -e dell-dset-collector >> $REDIRECT_OUTPUT 2>&1
		fi
		rpm -e dell-dset-common >> $REDIRECT_OUTPUT 2>&1
		PKGLIST=`grep "dell-dset-provider_basesfcb" /opt/dell/advdiags/dset/bin/packages/.sfcbpkglist -r`
		if [ "$PKGLIST" != "" ]; then
			rpm -e dell-dset-provider_basesfcb >> $REDIRECT_OUTPUT 2>&1
		fi
		PKGLIST=`grep "dell-dset-provider_basetog" /opt/dell/advdiags/dset/bin/packages/.sfcbpkglist -r`
		if [ "$PKGLIST" != "" ]; then
			rpm -e dell-dset-provider_basetog >> $REDIRECT_OUTPUT 2>&1
		fi
		PKGLIST=`grep "dell-dset-provider_basesfcb_Watchdog" /opt/dell/advdiags/dset/bin/packages/.sfcbpkglist -r`
		if [ "$PKGLIST" != "" ]; then
			rpm -e dell-dset-provider_basesfcb_Watchdog >> $REDIRECT_OUTPUT 2>&1
		fi
		rpm -e srvadmin-hapi >> $REDIRECT_OUTPUT 2>&1
		rpm -e srvadmin-storelib-sysfs >> $REDIRECT_OUTPUT 2>&1
		
		if [ "$DELETE_DSETSFCB" == "0" ] ; then
		
			if [ "$SFCB_chkconfig_init_Level" != "" ]; then
				if [ "$SFCB_init_Level_2" != "" ]; then
					chkconfig --level 2  $CIMOM_NAME off
				fi
				if [ "$SFCB_init_Level_3" != "" ]; then
					chkconfig --level 3  $CIMOM_NAME off
				fi
				if [ "$SFCB_init_Level_5" != "" ]; then
					chkconfig --level 5  $CIMOM_NAME off
				fi	
			fi 
	
			if [ "$CIMOM_ADDED" != "" ] ; then 		 
				chkconfig --del $CIMOM_NAME >> $REDIRECT_OUTPUT 2>&1
			fi

			PKGLIST=`grep "sblim-cmpi-base" /opt/dell/advdiags/dset/bin/packages/.sfcbpkglist -r`
			if [ "$PKGLIST" != "" ]; then
				rpm -e sblim-cmpi-base >> $REDIRECT_OUTPUT 2>&1
			fi

			PKGLIST=`grep "sblim-indication_helper" /opt/dell/advdiags/dset/bin/packages/.sfcbpkglist -r`
			if [ "$PKGLIST" != "" ]; then
				rpm -e sblim-indication_helper >> $REDIRECT_OUTPUT 2>&1
			fi

			PKGLIST=`grep "sblim-sfcb" /opt/dell/advdiags/dset/bin/packages/.sfcbpkglist -r`
			if [ "$PKGLIST" != "" ]; then
				rpm -e sblim-sfcb >> $REDIRECT_OUTPUT 2>&1
			fi
			PKGLIST=`grep "dell-dset-provider_basesfcb" /opt/dell/advdiags/dset/bin/packages/.sfcbpkglist -r`
			if [ "$PKGLIST" != "" ]; then
				rpm -e dell-dset-provider_basesfcb >> $REDIRECT_OUTPUT 2>&1
			fi
			PKGLIST=`grep "dell-dset-provider_basetog" /opt/dell/advdiags/dset/bin/packages/.sfcbpkglist -r`
			if [ "$PKGLIST" != "" ]; then
				rpm -e dell-dset-provider_basetog >> $REDIRECT_OUTPUT 2>&1
			fi
			PKGLIST=`grep "dell-dset-provider_basesfcb_Watchdog" /opt/dell/advdiags/dset/bin/packages/.sfcbpkglist -r`
			if [ "$PKGLIST" != "" ]; then
				rpm -e dell-dset-provider_basesfcb_Watchdog >> $REDIRECT_OUTPUT 2>&1
			fi
	 
			#Removing SFCB group from user root and reverting the state
			PKGLIST=`grep "sfcb_assign_root" /opt/dell/advdiags/dset/bin/packages/.sfcbpkglist -r`
			if [ "$PKGLIST" != "" ]; then
				gpasswd -d root sfcb >> $REDIRECT_OUTPUT 2>&1
			fi
	 
			#Deleting SFCB group user if added during installation
			PKGLIST=`grep "sfcb_group_add" /opt/dell/advdiags/dset/bin/packages/.sfcbpkglist -r`
			if [ "$PKGLIST" != "" ]; then
				groupdel sfcb >> $REDIRECT_OUTPUT 2>&1
			fi
		
			PKGLIST=`grep "cim-schema" /opt/dell/advdiags/dset/bin/packages/.sfcbpkglist -r`
			if [ "$PKGLIST" != "" ]; then
				rpm -e cim-schema >> $REDIRECT_OUTPUT 2>&1
			fi
	 
			SFCB_NOT_RUNNING=`grep "SFCB_NOT_RUNNING" /opt/dell/advdiags/dset/bin/packages/.sfcbpkglist -r`
			if [ "$SFCB_NOT_RUNNING" != "" ]; then
				SFCB_RUN_PRE_STATUS="NOT_RUNNING"
			fi
	 
			SFCB_RUNNING=`grep "SFCB_RUNNING" /opt/dell/advdiags/dset/bin/packages/.sfcbpkglist -r`
			if [ "$SFCB_RUNNING" != "" ]; then
				SFCB_RUN_PRE_STATUS="RUNNING"
			fi
		fi
	fi
  
	# Calling the aforementioned function for all the links made in initCIMOM.sh
	CheckLink_And_Delete /opt/dell/advdiags/dset/bin/libssl.so.1.0.0 /lib64/libssl.so.1.0.0?

	CheckLink_And_Delete /opt/dell/advdiags/dset/bin/libcrypto.so.1.0.0 /lib64/libcrypto.so.1.0.0?

	CheckLink_And_Delete /usr/lib64/libcurl.so.3 libcurl.so.4.1.1

	CheckLink_And_Delete /usr/lib64/libssl.so.10 libssl.so.1.0.0

	CheckLink_And_Delete /usr/lib64/libssl.so.6 libssl.so.1.0.0

	CheckLink_And_Delete /usr/lib/libcurl.so.3 /usr/lib/libcurl.so.4.1.?

	CheckLink_And_Delete /usr/lib64/libcurl.so.3 /usr/lib64/libcurl.so.4.1.?

    if [ "${TOGPEG_RUN_STATUS}" == "TRUE" ]; then
        PKGLIST=`grep "sblim-cmpi-base" /opt/dell/advdiags/dset/bin/packages/.sfcbpkglist -r`
		if [ "$PKGLIST" != "" ]; then
			rpm -e sblim-cmpi-base >> $REDIRECT_OUTPUT 2>&1
		fi

		PKGLIST=`grep "sblim-indication_helper" /opt/dell/advdiags/dset/bin/packages/.sfcbpkglist -r`
		if [ "$PKGLIST" != "" ]; then
			rpm -e sblim-indication_helper >> $REDIRECT_OUTPUT 2>&1
		fi
		
		PKGLIST=`grep "cim-schema" /opt/dell/advdiags/dset/bin/packages/.sfcbpkglist -r`
		if [ "$PKGLIST" != "" ]; then
			rpm -e cim-schema >> $REDIRECT_OUTPUT 2>&1
		fi
	fi
	if [ "${TOGPEG_RUN_STATUS}" == "FALSE" ]; then
		if [ "${SFCB_RUN_PRE_STATUS}" == "RUNNING" ]; then
			ACTION="restart"
		elif [ "${SFCB_RUN_PRE_STATUS}" == "NOT_RUNNING" ]; then
			ACTION="stop"
		fi
		# ACTION is decided, now is the turn to perform it
		if [ "$ACTION" != "NONE" ]; then
			if [ -f /etc/vmware-release ]; then
				/etc/init.d/sfcbd-watchdog $ACTION >> $REDIRECT_OUTPUT 2>&1
			elif [ -f /etc/init.d/sfcb ]; then
				/etc/init.d/sfcb $ACTION >> $REDIRECT_OUTPUT 2>&1
			elif [ -f /etc/init.d/sblim-sfcb ]; then
				/etc/init.d/sblim-sfcb $ACTION >> $REDIRECT_OUTPUT 2>&1
			fi
		fi
	fi

else
	rpm -e dell-dset-collector >> $REDIRECT_OUTPUT 2>&1
	rpm -e dell-dset-common >> $REDIRECT_OUTPUT 2>&1
fi
 
rpm -q srvadmin-omacore >> $REDIRECT_OUTPUT 2>&1
if test $? -ne 0; then
	rpm -q srvadmin-hapi >> $REDIRECT_OUTPUT 2>&1
	if test $? -eq 0; then
		echo "" >> $REDIRECT_OUTPUT
	else
		rm -rf /opt/dell/srvadmin
	fi
fi

# Delete /opt/dell/advdiags only if collector is not pre-installed
rpm -q dell-dset-common >> $REDIRECT_OUTPUT 2>&1
if test $? -ne 0; then
	rm -rf /opt/dell/advdiags
fi